<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hai vida más allá del restolador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Llicencia pa: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ye Software Llibre pero lleva un tiempu valoratible desendolcalu.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;fai una donación&lt;/a&gt; pa sofitar el desendolcu continuu de %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduz %1 a la to llingua nativa usando %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Iconu diseñáu por %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lliberáu baxo la &lt;a href=&apos;%1&apos;&gt;Llicencia Pública Xeneral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zarrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tocante a</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introduz los detalles de la llicencia</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>Cor&amp;réu-e:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Códigu:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Obtén una llicencia de %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demo caducó</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Ensin una llicencia, l&apos;aplicación va caducar en %1 díes.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Al mercar la versión completa, tamién sofites el trabayu fechu na creación de %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar demostración</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introducir llicencia</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Mercar llicencia</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Added</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Most Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 reproducciones</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restantes</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 descargáu en %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descarga finada</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Camudar llocalización...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escueyi la llocalización de les descargues</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Ubicación pa descargues modificada.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Les descargues en cursu van dir a la llocalización anterior.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Descargando a: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descargues</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Dexar de reproducir tres la pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Xubir volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Baxar volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Callar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Guetar p&apos;alantre</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Guetar p&apos;atrás</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Atopar vídeos y canales por pallabres clave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Restolar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Guetar vídeos por categoría</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Ponte cómodu</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Fallu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>A&amp;menorgar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener la reproducción y volver a la gueta</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>A&amp;nterior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Tornar a la pista anterior</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Omitir videu y saltar al siguiente</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Re&amp;producir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar la reproducción</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Pasar a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>M&amp;ou compautu</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Anubrir la llista de reproducción y la barra de ferramientes</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir la páxina de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Dir a la páxina del videu en YouTube y posar la reproducción</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar l&apos;en&amp;llaz de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar l&apos;enllaz a YouTube del videu actual nel cartafueyu</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar la &amp;URL de fluxu del videu</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar la URL actual del fluxu del videu al cartafueyu</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Alcontrar &amp;partes de vídeos</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Alcontrar otres partes de vídeos, con suerte nel orde correutu</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Desanicia&amp;r</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Quitar los vídeos seleicionaos de la llista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>X&amp;ubir</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover hacia arriba na llista de reproducción los vídeos seleicionaos</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Baxar</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover hacia abaxo na llista de reproducción los vídeos seleicionaos</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Llimpiar guetes recientes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Llimpiar l&apos;historial de guetes. Nun pue desfacese.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Alón</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Páxina &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Facer una &amp;donación</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, sofita&apos;l desendolcu continuu de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Tocante &amp;a</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información tocante a %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar volume</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Comenzar la reproducción &amp;manualmente</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Comenzar la reproducción de vídeos manualmente</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargues</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Amosar detalles sobre les descargues de vídeos</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descargar</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Descargar el videu actual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Compartir el videu actual usando %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>Cor&amp;réu-e:</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Corréu-e</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zarrar</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Flotar na parte superior</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Detener tres d&apos;esti videu</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Informar de un problema...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Refinar la gueta...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Más...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;rellacionaos</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Ver vídeos rellacionaos col actual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>¿&amp;Préstate %1? ¡Puntúalo!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Mercar %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Re&amp;producción</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Llista de reprod.</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Videu</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Calca %1 pa xubir el volume, %2 pa baxalu</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Escueyi la llocalización pal conteníu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>¿Quies salir de %1 con una descarga en cursu?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si zarres %1 agora, esta descarga va encaboxase.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zarrar y encaboxar descarga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Esperar a que fine la descarga</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fallu: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Posar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Posar reproducción</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Salir de pan&amp;talla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempu faltante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume silenciáu</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume activu</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolución máxima de videu afitada en %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>La to privacidá agora ta asegurada</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descargues completes</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versión %2 yá ta disponible.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Avisame más sero</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Anovar</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora pues apegar la URL del fluxu de videu n&apos;otra aplicación</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>L&apos;enllaz ye válidu namái por un tiempu llimitáu.</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Esto ye namái la versión de prueba de %1.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descargando %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodiu</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Unviáu dende %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Hai disponible una versión nueva de %1.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 ta disponible agora. Tienes %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>¿Quies descargala agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Omitir esta versión</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Avisame más sero</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar anovamientu</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Apegar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completáu</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Paráu</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Detener la descarga</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Amosar en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir carpeta contenedora</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reaniciar la descarga</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Amosar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nun hai vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nun hai más vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Númberu de visites</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Valoración</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Cualquier momentu</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Güei</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 díes</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 díes</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Too</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Curtiu</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mediu</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Llargu</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menos de 4 minutos</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Ente 4 y 20 minutos</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Mayor de 20 minutos</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidá</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Alta definición</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p o mayor</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fecho</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Fecho</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienveníu a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>pa entamar a ver vídeos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>una pallabra clave</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Escribi</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Pallabres clave recientes</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canales recientes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Consigui la versión completa</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Dir a %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Regresar a %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>&amp;Refinar la gueta...</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Quixisti dicir: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Camudar llocalización...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Más populares</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descargando anovamientu...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>L&apos;Arxentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bélxica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>El Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>El Canadá</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República Checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>L&apos;Exiptu</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemaña</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Ḥong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Xapón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Xordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malasia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Méxicu</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marruecos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Los Países Baxos</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nueva Zelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nixeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipines</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sudáfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Corea del Sur</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwán</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunicia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquía</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiratos Árabes Xuníos</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Reinu Xuníu</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Tol mundu</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nun pue obtenese&apos;l fluxu de videu pa %1</translation>
    </message>
</context>
</TS>